Learn R Programming

migrbc (version 2.0.9)

check_and_tidy_date: Validate general dates

Description

A function to check the date variable whether is the right date. This is an internal function.

Usage

check_and_tidy_date(date, date_name)

Arguments

date

A date object in string format such as '2018-01-01'.

date_name

The name of the date variable.

Value

A verified date object in string format