Learn R Programming

migrbc (version 2.0.9)

check_and_tidy_date_crossing: Validate dates on border crossing.

Description

A function to check the date variable whether is the right date. This is an internal function.

Usage

check_and_tidy_date_crossing(date_crossing)

Arguments

date_crossing

The border crossing date.

Value

The border crossing date that has been verified and tidied up.